@@ -4,7 +4,7 @@ use warnings;
 package YAML::PP;
 use B;
 
-our $VERSION = '0.005_002'; # TRIAL VERSION
+our $VERSION = '0.006_001'; # TRIAL VERSION
 
 use base 'Exporter';
 our @EXPORT_OK = qw/ Load LoadFile Dump DumpFile /;
@@ -261,7 +261,6 @@ sub load_scalar_tag {
             }
             return $res;
         }
-        die "Tag $tag ($value)";
     }
     if (my $regex = $res->{regex}) {
         for my $item (@$regex) {
@@ -421,10 +420,18 @@ sub register {
             return { plain => "$value" };
         },
     );
+    my %special = ( NaN => '.nan', Inf => '.inf', '-Inf' => '-.inf' );
     $schema->add_representer(
         flags => $float_flags,
         code => sub {
             my ($rep, $value) = @_;
+            # TODO is inf/nan supported in YAML JSON Schema?
+            if (exists $special{ $value }) {
+                return { plain => "$value" };
+            }
+            if (int($value) eq $value and not $value =~ m/\./) {
+                $value .= '.0';
+            }
             return { plain => "$value" };
         },
     );
@@ -495,6 +502,18 @@ sub register {
         tag => 'tag:yaml.org,2002:float',
         match => [ regex => $RE_FLOAT_CORE => \&YAML::PP::Schema::JSON::_to_float ],
     );
+    $schema->add_resolver(
+        tag => 'tag:yaml.org,2002:float',
+        match => [ equals => $_ => 0 + "inf" ],
+    ) for (qw/ .inf .Inf .INF /);
+    $schema->add_resolver(
+        tag => 'tag:yaml.org,2002:float',
+        match => [ equals => $_ => 0 - "inf" ],
+    ) for (qw/ -.inf -.Inf -.INF /);
+    $schema->add_resolver(
+        tag => 'tag:yaml.org,2002:float',
+        match => [ equals => $_ => 0 + "nan" ],
+    ) for (qw/ .nan .NaN .NAN /);
     $schema->add_resolver(
         tag => 'tag:yaml.org,2002:str',
         match => [ regex => qr{^(.*)$} => sub { $_[0] } ],
@@ -517,10 +536,17 @@ sub register {
             return { plain => "$value" };
         },
     );
+    my %special = ( NaN => '.nan', Inf => '.inf', '-Inf' => '-.inf' );
     $schema->add_representer(
         flags => $float_flags,
         code => sub {
             my ($rep, $value) = @_;
+            if (exists $special{ $value }) {
+                return { plain => $special{ $value } };
+            }
+            if (int($value) eq $value and not $value =~ m/\./) {
+                $value .= '.0';
+            }
             return { plain => "$value" };
         },
     );
